@@ -55,7 +55,15 @@ class FunctionsTest(SupyTestCase):
 
 class AkaChannelTestCase(ChannelPluginTestCase):
     plugins = ('Aka', 'Conditional', 'Filter', 'Math', 'Utilities',
-            'Format', 'Reply')
+            'Format', 'Reply', 'String')
+
+    def testHistsearch(self):
+        self.assertNotError(
+                r'aka add histsearch "last --from [cif true '
+                r'\"echo test\" \"echo test\"] '
+                r'--regexp [concat \"m/$1/\" [re s/g// \"@2\"]]"')
+        self.assertResponse('echo foo', 'foo')
+        self.assertResponse('histsearch .*', '@echo foo')
 
     def testDoesNotOverwriteCommands(self):
         # We don't have dispatcher commands anymore
@@ -206,6 +214,11 @@ class AkaChannelTestCase(ChannelPluginTestCase):
         self.assertResponse('a+ spam echo egg', 'The operation succeeded.')
         self.assertResponse('spam', 'egg')
 
+    def testIgnore(self):
+        self.assertResponse('aka add test ignore', 'The operation succeeded.')
+        self.assertNoResponse('test')
+
+
 class AkaTestCase(PluginTestCase):
     plugins = ('Aka', 'Alias', 'User', 'Utilities')
 
