@@ -70,8 +70,8 @@ class Channel(callbacks.Plugin):
                                   channel, msg.prefix)
                     irc.sendMsg(networkGroup.channels.join(channel))
             else:
-                self.log.info('Kicked from %s by %s. Not auto-rejoining.' %
-                        (channel, msg.prefix))
+                self.log.info('Kicked from %s by %s. Not auto-rejoining.',
+                        channel, msg.prefix)
 
     def _sendMsg(self, irc, msg):
         irc.queueMsg(msg)
@@ -265,7 +265,7 @@ class Channel(callbacks.Plugin):
 
     @internationalizeDocstring
     def cycle(self, irc, msg, args, channel, reason):
-        """[<channel>]
+        """[<channel>] [<reason>]
 
         If you have the #channel,op capability, this will cause the bot to
         "cycle", or PART and then JOIN the channel. <channel> is only necessary
@@ -549,7 +549,7 @@ class Channel(callbacks.Plugin):
             Returns the channels in which this bot is lobotomized.
             """
             L = []
-            for (channel, c) in ircdb.channels.iteritems():
+            for (channel, c) in ircdb.channels.items():
                 if c.lobotomized:
                     chancap = ircdb.makeChannelCapability(channel, 'op')
                     if ircdb.checkCapability(msg.prefix, 'admin') or \
@@ -663,7 +663,7 @@ class Channel(callbacks.Plugin):
 
         @internationalizeDocstring
         def remove(self, irc, msg, args, channel, banmask):
-            """[<channel>] <hostmask>
+            """[<channel>] <nick|hostmask>
 
             If you have the #channel,op capability, this will remove the
             persistent ignore on <hostmask> in the channel. <channel> is only
@@ -676,7 +676,7 @@ class Channel(callbacks.Plugin):
                 irc.replySuccess()
             except KeyError:
                 irc.error(_('There are no ignores for that hostmask.'))
-        remove = wrap(remove, ['op', 'hostmask'])
+        remove = wrap(remove, ['op', 'banmask'])
 
         @internationalizeDocstring
         def list(self, irc, msg, args, channel):
@@ -909,10 +909,9 @@ class Channel(callbacks.Plugin):
         # Make sure we don't elicit information about private channels to
         # people or channels that shouldn't know
         capability = ircdb.makeChannelCapability(channel, 'op')
-        hostmask = irc.state.nickToHostmask(msg.nick)
         if 's' in irc.state.channels[channel].modes and \
             msg.args[0] != channel and \
-            not ircdb.checkCapability(hostmask, capability) and \
+            not ircdb.checkCapability(msg.prefix, capability) and \
             (ircutils.isChannel(msg.args[0]) or \
              msg.nick not in irc.state.channels[channel].users):
             irc.error(_('You don\'t have access to that information.'),
@@ -937,8 +936,7 @@ class Channel(callbacks.Plugin):
         if frm is not None:
             s += format(_(' (from %s)'), frm)
         for nick in irc.state.channels[channel].users:
-            hostmask = irc.state.nickToHostmask(nick)
-            if ircdb.checkCapability(hostmask, capability):
+            if ircdb.checkCapability(msg.prefix, capability):
                 irc.reply(s, to=nick, private=True)
         irc.replySuccess()
 
@@ -969,8 +967,7 @@ class Channel(callbacks.Plugin):
             else:
                 irc.error(Raise=True)
         capability = ircdb.makeChannelCapability(channel, 'op')
-        hostmask = irc.state.nickToHostmask(msg.nick)
-        if not ircdb.checkCapabilities(hostmask, [capability, 'admin']):
+        if not ircdb.checkCapabilities(msg.prefix, [capability, 'admin']):
             irc.errorNoCapability(capability, Raise=True)
         try:
             network = conf.supybot.networks.get(irc.network)
