@@ -47,7 +47,9 @@ __contributors__ = {supybot.Author('Keith Jones', 'kmj', ''): ['convert']}
 from . import config
 from . import plugin
 from imp import reload
+from .local import convertcore
 reload(plugin) # In case we're being reloaded.
+reload(convertcore)
 
 if world.testing:
     from . import test
