@@ -43,10 +43,7 @@ import supybot.callbacks as callbacks
 from supybot.i18n import PluginInternationalization, internationalizeDocstring
 _ = PluginInternationalization('Math')
 
-try:
-    from .local import convertcore
-except ImportError:
-    from .local import convertcore
+from .local import convertcore
 
 baseArg = ('int', 'base', lambda i: i <= 36)
 
