@@ -32,13 +32,12 @@ import sys
 import time
 import string
 
-from cStringIO import StringIO
-
 import supybot.conf as conf
 import supybot.ircdb as ircdb
 import supybot.utils as utils
 import supybot.shlex as shlex
 from supybot.commands import *
+import supybot.utils.minisix as minisix
 import supybot.plugins as plugins
 import supybot.ircutils as ircutils
 import supybot.callbacks as callbacks
@@ -69,7 +68,7 @@ class OptionList(object):
                 ret.append(token)
 
     def tokenize(self, s):
-        lexer = shlex.shlex(StringIO(s))
+        lexer = shlex.shlex(minisix.io.StringIO(s))
         lexer.commenters = ''
         lexer.quotes = ''
         lexer.whitespace = ''
@@ -94,7 +93,7 @@ class SqliteMoobotDB(object):
         self.dbs = ircutils.IrcDict()
 
     def close(self):
-        for db in self.dbs.itervalues():
+        for db in self.dbs.values():
             db.close()
         self.dbs.clear()
 
@@ -107,12 +106,12 @@ class SqliteMoobotDB(object):
         
         if os.path.exists(filename):
             db = sqlite3.connect(filename, check_same_thread=False)
-            if sys.version_info[0] < 3:
+            if minisix.PY2:
                 db.text_factory = str
             self.dbs[channel] = db
             return db
         db = sqlite3.connect(filename, check_same_thread=False)
-        if sys.version_info[0] < 3:
+        if minisix.PY2:
             db.text_factory = str
         self.dbs[channel] = db
         cursor = db.cursor()
