@@ -92,8 +92,9 @@ class Plugin(callbacks.Plugin):
         for cb in irc.callbacks:
             if not hasattr(cb, 'getCommand'):
                 continue
-            commandlist = cb.getCommand(command)
-            if commandlist:
+            longest_matching_command = cb.getCommand(command)
+            if len(longest_matching_command) >= len(command):
+                # Actually, this is equivalent to use ==
                 plugin_list.append(cb.name())
         return plugin_list
 
@@ -113,7 +114,7 @@ class Plugin(callbacks.Plugin):
                     plugin = 'plugins'
                 else:
                     plugin = 'plugin'
-                irc.reply(format('The %q command is available in the %L %s.',
+                irc.reply(format(_('The %q command is available in the %L %s.'),
                                  command, L, plugin))
         else:
             irc.error(format('There is no command %q.', command))
@@ -162,7 +163,7 @@ class Plugin(callbacks.Plugin):
             Sort the list of 'long names' based on the number of contributions
             associated with each.
             """
-            L = module.__contributors__.items()
+            L = list(module.__contributors__.items())
             def negativeSecondElement(x):
                 return -len(x[1])
             utils.sortBy(negativeSecondElement, L)
