@@ -37,6 +37,7 @@ import supybot.dbi as dbi
 import supybot.conf as conf
 import supybot.utils as utils
 from supybot.commands import *
+import supybot.utils.minisix as minisix
 import supybot.ircmsgs as ircmsgs
 import supybot.plugins as plugins
 import supybot.ircutils as ircutils
@@ -73,7 +74,7 @@ class SqliteQuoteGrabsDB(object):
         self.filename = filename
 
     def close(self):
-        for db in self.dbs.itervalues():
+        for db in self.dbs.values():
             db.close()
 
     def _getDb(self, channel):
@@ -86,13 +87,13 @@ class SqliteQuoteGrabsDB(object):
             return self.dbs[filename]
         if os.path.exists(filename):
             db = sqlite3.connect(filename)
-            if sys.version_info[0] < 3:
+            if minisix.PY2:
                 db.text_factory = str
             db.create_function('nickeq', 2, p)
             self.dbs[filename] = db
             return db
         db = sqlite3.connect(filename)
-        if sys.version_info[0] < 3:
+        if minisix.PY2:
             db.text_factory = str
         db.create_function('nickeq', 2, p)
         self.dbs[filename] = db
@@ -279,7 +280,7 @@ class QuoteGrabs(callbacks.Plugin):
         # opposed to channel which is used to determine which db to store the
         # quote in
         chan = msg.args[0]
-        if chan is None or not ircutils.isChannel(chan):
+        if chan is None or not irc.isChannel(chan):
             raise callbacks.ArgumentError
         if ircutils.nickEqual(nick, msg.nick):
             irc.error(_('You can\'t quote grab yourself.'), Raise=True)
