@@ -52,6 +52,11 @@ import supybot.callbacks as callbacks
 from supybot.i18n import PluginInternationalization, internationalizeDocstring
 _ = PluginInternationalization('RSS')
 
+if world.testing:
+    INIT_DELAY = 1
+else:
+    INIT_DELAY = 10
+
 if minisix.PY2:
     from urllib2 import ProxyHandler
 else:
@@ -101,7 +106,7 @@ class Feed:
         self.data = None
         # We don't want to fetch feeds right after the plugin is
         # loaded (the bot could be starting, and thus already busy)
-        self.last_update = time.time() if plugin_is_loading else 0
+        self.last_update = 0
         self.entries = []
         self.etag = None
         self.modified = None
@@ -172,6 +177,12 @@ class RSS(callbacks.Plugin):
     def __init__(self, irc):
         self.__parent = super(RSS, self)
         self.__parent.__init__(irc)
+
+        if world.starting:
+            self._init_time = time.time() # To delay loading the feeds
+        else:
+            self._init_time = 0
+
         # Scheme: {name: url}
         self.feed_names = callbacks.CanonicalNameDict()
         # Scheme: {url: feed}
@@ -226,7 +237,13 @@ class RSS(callbacks.Plugin):
     def register_feed_config(self, name, url=''):
         self.registryValue('feeds').add(name)
         group = self.registryValue('feeds', value=False)
-        conf.registerGlobalValue(group, name, registry.String(url, ''))
+        conf.registerGlobalValue(group, name,
+                                 registry.String(url, """The URL for the feed
+                                                 %s. Note that because
+                                                 announced lines are cached,
+                                                 you may need to reload this
+                                                 plugin after changing this
+                                                 option.""" % name))
         feed_group = conf.registerGroup(group, name)
         conf.registerChannelValue(feed_group, 'format',
                 registry.String('', _("""Feed-specific format. Defaults to
@@ -314,16 +331,9 @@ class RSS(callbacks.Plugin):
             (initial, feed.initial) = (feed.initial, False)
         self.announce_feed(feed, initial)
 
-    def update_feed_in_thread(self, feed):
-        feed.last_update = time.time()
-        t = world.SupyThread(target=self.update_feed,
-                             name=format('Fetching feed %u', feed.url),
-                             args=(feed,))
-        t.setDaemon(True)
-        t.start()
-
     def update_feed_if_needed(self, feed):
-        if self.is_expired(feed):
+        if self.is_expired(feed) and \
+                self._init_time + INIT_DELAY < time.time():
             self.update_feed(feed)
 
     @only_one_at_once
@@ -367,13 +377,12 @@ class RSS(callbacks.Plugin):
                 if feed.name not in self.registryValue('announce', channel):
                     continue
                 if initial:
-                    n = self.registryValue('initialAnnounceHeadlines', channel)
-                    if n:
-                        announced_entries = new_entries[0:n]
-                    else:
-                        announced_entries = []
+                    max_entries = \
+                            self.registryValue('initialAnnounceHeadlines', channel)
                 else:
-                    announced_entries = new_entries
+                    max_entries = \
+                            self.registryValue('maximumAnnounceHeadlines', channel)
+                announced_entries = new_entries[0:max_entries]
                 announced_entries = sort_feed_items(announced_entries, order)
                 for entry in announced_entries:
                     self.announce_entry(irc, channel, feed, entry)
