@@ -1,6 +1,6 @@
 ###
 # Copyright (c) 2002-2004, Jeremiah Fincher
-# Copyright (c) 2010, James McCoy
+# Copyright (c) 2010,2015 James McCoy
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -49,21 +49,9 @@ class Relay(callbacks.Plugin):
         self.__parent = super(Relay, self)
         self.__parent.__init__(irc)
         self._whois = {}
-        self.lastmsg = {}
-        self.ircstates = {}
         self.queuedTopics = MultiSet()
         self.lastRelayMsgs = ircutils.IrcDict()
 
-    def __call__(self, irc, msg):
-        try:
-            irc = self._getRealIrc(irc)
-            if irc not in self.ircstates:
-                self._addIrc(irc)
-            self.ircstates[irc].addMsg(irc, self.lastmsg[irc])
-        finally:
-            self.lastmsg[irc] = msg
-        self.__parent.__call__(irc, msg)
-
     def do376(self, irc, msg):
         networkGroup = conf.supybot.networks.get(irc.network)
         for channel in self.registryValue('channels'):
@@ -82,19 +70,6 @@ class Relay(callbacks.Plugin):
         # We should allow abbreviations at some point.
         return irc.network
 
-    def _addIrc(self, irc):
-        # Let's just be extra-special-careful here.
-        if irc not in self.ircstates:
-            self.ircstates[irc] = irclib.IrcState()
-        if irc not in self.lastmsg:
-            self.lastmsg[irc] = ircmsgs.ping('this is just a fake message')
-        if irc.afterConnect:
-            # We've probably been reloaded.  Let's send some messages to get
-            # our IrcState objects up to current.
-            for channel in self.registryValue('channels'):
-                irc.queueMsg(ircmsgs.who(channel))
-                irc.queueMsg(ircmsgs.names(channel))
-
     @internationalizeDocstring
     def join(self, irc, msg, args, channel):
         """[<channel>]
@@ -202,64 +177,9 @@ class Relay(callbacks.Plugin):
         if (irc, loweredNick) not in self._whois:
             return
         (replyIrc, replyMsg, d) = self._whois[(irc, loweredNick)]
-        hostmask = '@'.join(d['311'].args[2:4])
-        user = d['311'].args[-1]
-        if '319' in d:
-            channels = d['319'].args[-1].split()
-            ops = []
-            voices = []
-            normal = []
-            halfops = []
-            for channel in channels:
-                if channel.startswith('@'):
-                    ops.append(channel[1:])
-                elif channel.startswith('%'):
-                    halfops.append(channel[1:])
-                elif channel.startswith('+'):
-                    voices.append(channel[1:])
-                else:
-                    normal.append(channel)
-            L = []
-            if ops:
-                L.append(format(_('is an op on %L'), ops))
-            if halfops:
-                L.append(format(_('is a halfop on %L'), halfops))
-            if voices:
-                L.append(format(_('is voiced on %L'), voices))
-            if normal:
-                if L:
-                    L.append(format(_('is also on %L'), normal))
-                else:
-                    L.append(format(_('is on %L'), normal))
-        else:
-            L = [_('isn\'t on any non-secret channels')]
-        channels = format('%L', L)
-        if '317' in d:
-            idle = utils.timeElapsed(d['317'].args[2])
-            signon = time.strftime(conf.supybot.reply.format.time(),
-                                   time.localtime(float(d['317'].args[3])))
-        else:
-            idle = _('<unknown>')
-            signon = _('<unknown>')
-        if '312' in d:
-            server = d['312'].args[2]
-        else:
-            server = _('<unknown>')
-        if '301' in d:
-            away = format(_('  %s is away: %s.'), nick, d['301'].args[2])
-        else:
-            away = ''
-        if '320' in d:
-            if d['320'].args[2]:
-                identify = _(' identified')
-            else:
-                identify = ''
-        else:
-            identify = ''
-        s = format(_('%s (%s) has been%s on server %s since %s (idle for %s) '
-                   'and %s.%s'),
-                   user, hostmask, identify, server, signon, idle,
-                   channels, away)
+        d['318'] = msg
+        s = ircutils.formatWhois(irc, d, caller=replyMsg.nick,
+                                 channel=replyMsg.args[0])
         replyIrc.reply(s)
         del self._whois[(irc, loweredNick)]
 
@@ -447,10 +367,8 @@ class Relay(callbacks.Plugin):
         network = self._getIrcName(irc)
         s = format(_('nick change by %s to %s on %s'), msg.nick,newNick,network)
         for channel in self.registryValue('channels'):
-            if channel in irc.state.channels:
-                if newNick in irc.state.channels[channel].users:
-                    m = self._msgmaker(channel, s)
-                    self._sendToOthers(irc, m)
+            m = self._msgmaker(channel, s)
+            self._sendToOthers(irc, m)
 
     def doTopic(self, irc, msg):
         irc = self._getRealIrc(irc)
@@ -488,10 +406,8 @@ class Relay(callbacks.Plugin):
         else:
             s = format(_('%s has quit %s.'), msg.nick, network)
         for channel in self.registryValue('channels'):
-            if channel in self.ircstates[irc].channels:
-                if msg.nick in self.ircstates[irc].channels[channel].users:
-                    m = self._msgmaker(channel, s)
-                    self._sendToOthers(irc, m)
+            m = self._msgmaker(channel, s)
+            self._sendToOthers(irc, m)
 
     def doError(self, irc, msg):
         irc = self._getRealIrc(irc)
