@@ -28,9 +28,14 @@
 # POSSIBILITY OF SUCH DAMAGE.
 ###
 
-import dynamicScope
+from . import dynamicScope
 
+from . import i18n
+
+builtins = (__builtins__ if isinstance(__builtins__, dict) else __builtins__.__dict__)
+builtins['supybotInternationalization'] = i18n.PluginInternationalization()
 from . import utils
+del builtins['supybotInternationalization']
 
 (__builtins__ if isinstance(__builtins__, dict) else __builtins__.__dict__)['format'] = utils.str.format
 
