@@ -498,7 +498,7 @@ class RichReplyMethods(object):
                     msg = self.reply(prefixer(s), **kwargs)
             return msg
 
-    def noReply(self):
+    def noReply(self, msg=None):
         self.repliedTo = True
 
     def _error(self, s, Raise=False, **kwargs):
@@ -1011,6 +1011,20 @@ class NestedCommandsIrcProxy(ReplyIrcProxy):
                 self.args[self.counter] = s
             self.evalArgs()
 
+    def noReply(self, msg=None):
+        if msg is None:
+            msg = self.msg
+        super(NestedCommandsIrcProxy, self).noReply(msg=msg)
+        if self.finalEvaled:
+            if isinstance(self.irc, NestedCommandsIrcProxy):
+                self.irc.noReply(msg=msg)
+            else:
+                msg.tag('ignored', True)
+        else:
+            self.args.pop(self.counter)
+            msg.tag('ignored', False)
+            self.evalArgs()
+
     def replies(self, L, prefixer=None, joiner=None,
                 onlyPrefixFirst=False, to=None,
                 oneToOne=None, **kwargs):
