@@ -1,6 +1,6 @@
 ###
 # Copyright (c) 2002-2005, Jeremiah Fincher
-# Copyright (c) 2009-2010, James McCoy
+# Copyright (c) 2009-2010,2015, James McCoy
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -33,7 +33,6 @@ Includes wrappers for commands.
 """
 
 import time
-import Queue
 import getopt
 import inspect
 import threading
@@ -44,7 +43,9 @@ try:
 except ImportError: # Windows!
     resource = None
 
-from . import callbacks, conf, ircdb, ircmsgs, ircutils, log, utils, world
+from . import callbacks, conf, ircdb, ircmsgs, ircutils, log, \
+        utils, world
+from .utils import minisix
 from .i18n import PluginInternationalization, internationalizeDocstring
 _ = PluginInternationalization()
 
@@ -78,7 +79,9 @@ def process(f, *args, **kwargs):
     <pn>, the pluginname, and <cn>, the command name, are strings used to
     create the process name, for identification purposes.
     <timeout>, if supplied, limits the length of execution of target 
-    function to <timeout> seconds."""
+    function to <timeout> seconds.
+    <heap_size>, if supplied, limits the memory used by the target
+    function."""
     timeout = kwargs.pop('timeout', None)
     heap_size = kwargs.pop('heap_size', None)
     if resource and heap_size is None:
@@ -123,7 +126,7 @@ def process(f, *args, **kwargs):
         raise ProcessTimeoutError("%s aborted due to timeout." % (p.name,))
     try:
         v = q.get(block=False)
-    except Queue.Empty:
+    except minisix.queue.Empty:
         return None
     finally:
         q.close()
@@ -265,14 +268,14 @@ def getInt(irc, msg, args, state, type=_('integer'), p=None):
 
 def getNonInt(irc, msg, args, state, type=_('non-integer value')):
     try:
-        i = _int(args[0])
+        _int(args[0])
         state.errorInvalid(type, args[0])
     except ValueError:
         state.args.append(args.pop(0))
 
 def getLong(irc, msg, args, state, type='long'):
     getInt(irc, msg, args, state, type)
-    state.args[-1] = long(state.args[-1])
+    state.args[-1] = minisix.long(state.args[-1])
 
 def getFloat(irc, msg, args, state, type=_('floating point number')):
     try:
@@ -302,7 +305,7 @@ def getId(irc, msg, args, state, kind=None):
     try:
         args[0] = args[0].lstrip('#')
         getInt(irc, msg, args, state, type=type)
-    except Exception as e:
+    except Exception:
         args[0] = original
         raise
 
@@ -397,9 +400,9 @@ def getHostmask(irc, msg, args, state):
 def getBanmask(irc, msg, args, state):
     getHostmask(irc, msg, args, state)
     getChannel(irc, msg, args, state)
-    channel = state.channel
     banmaskstyle = conf.supybot.protocols.irc.banmask
-    state.args[-1] = banmaskstyle.makeBanmask(state.args[-1])
+    state.args[-1] = banmaskstyle.makeBanmask(state.args[-1],
+            channel=state.channel)
 
 def getUser(irc, msg, args, state):
     try:
@@ -430,7 +433,7 @@ def _getRe(f):
         s = args.pop(0)
         def isRe(s):
             try:
-                foo = f(s)
+                f(s)
                 return True
             except ValueError:
                 return False
@@ -443,13 +446,14 @@ def _getRe(f):
                 else:
                     state.args.append(s)
             else:
-                state.errorInvalid(_('regular expression'), s)
-        except IndexError:
+                raise ValueError
+        except (ValueError, IndexError):
             args[:] = original
             state.errorInvalid(_('regular expression'), s)
     return get
 
 getMatcher = _getRe(utils.str.perlReToPythonRe)
+getMatcherMany = _getRe(utils.str.perlReToFindall)
 getReplacer = _getRe(utils.str.perlReToReplacer)
 
 def getNick(irc, msg, args, state):
@@ -464,7 +468,7 @@ def getNick(irc, msg, args, state):
 
 def getSeenNick(irc, msg, args, state, errmsg=None):
     try:
-        foo = irc.state.nickToHostmask(args[0])
+        irc.state.nickToHostmask(args[0])
         state.args.append(args.pop(0))
     except KeyError:
         if errmsg is None:
@@ -680,7 +684,7 @@ def getMatch(irc, msg, args, state, regexp, errmsg):
 
 def getLiteral(irc, msg, args, state, literals, errmsg=None):
     # ??? Should we allow abbreviations?
-    if isinstance(literals, basestring):
+    if isinstance(literals, minisix.string_types):
         literals = (literals,)
     abbrevs = utils.abbrev(literals)
     if args[0] in abbrevs:
@@ -772,6 +776,7 @@ wrappers = ircutils.IrcDict({
     'private': private,
     'public': public,
     'regexpMatcher': getMatcher,
+    'regexpMatcherMany': getMatcherMany,
     'regexpReplacer': getReplacer,
     'seenNick': getSeenNick,
     'something': getSomething,
@@ -825,7 +830,7 @@ class context(object):
             self.converter = getConverter(spec[0])
         elif spec is None:
             self.converter = getConverter('anything')
-        elif isinstance(spec, basestring):
+        elif isinstance(spec, minisix.string_types):
             self.args = ()
             self.converter = getConverter(spec)
         else:
@@ -847,7 +852,7 @@ class rest(context):
             args[:] = [' '.join(args)]
             try:
                 super(rest, self).__call__(irc, msg, args, state)
-            except Exception as e:
+            except Exception:
                 args[:] = original
         else:
             raise IndexError
@@ -951,7 +956,7 @@ class commalist(context):
                     if part: # trailing commas
                         super(commalist, self).__call__(irc, msg, [part], st)
             state.args.append(st.args)
-        except Exception as e:
+        except Exception:
             args[:] = original
             raise
 
@@ -963,7 +968,7 @@ class getopts(context):
         self.getopts = {}
         self.getoptL = []
         self.getoptLs = ''
-        for (name, spec) in getopts.iteritems():
+        for (name, spec) in getopts.items():
             if spec == '':
                 if len(name) == 1:
                     self.getoptLs += name
@@ -1023,7 +1028,7 @@ class State(object):
 
     def essence(self):
         st = State(self.types)
-        for (attr, value) in self.__dict__.iteritems():
+        for (attr, value) in self.__dict__.items():
             if attr not in ('args', 'kwargs'):
                 setattr(st, attr, value)
         return st
