@@ -346,9 +346,7 @@ def registerNetwork(name, password='', ssl=True, sasl_username='',
         registry.String('', _("""A certificate that is trusted to verify
         certificates of this network (aka. Certificate Authority).""")))
     registerGlobalValue(network, 'requireStarttls', registry.Boolean(False,
-        _("""Determines whether the bot will connect in plain text to %s
-        but require STARTTLS before authentication. This is ignored if the
-        connection already uses SSL.""") % name))
+        _("""Deprecated config value, keep it to False.""")))
 
     registerGlobalValue(network, 'certfile', registry.String('',
         _("""Determines what certificate file (if any) the bot will use to
@@ -1246,15 +1244,18 @@ class IP(registry.String):
         else:
             registry.String.setValue(self, v)
 
+class ListOfIPs(registry.SpaceSeparatedListOfStrings):
+    Value = IP
+
 registerGlobalValue(supybot.servers.http, 'singleStack',
     registry.Boolean(True, _("""If true, uses IPV6_V6ONLY to disable
     forwaring of IPv4 traffic to IPv6 sockets. On *nix, has the same
     effect as setting kernel variable net.ipv6.bindv6only to 1.""")))
 registerGlobalValue(supybot.servers.http, 'hosts4',
-    IP('0.0.0.0', _("""Space-separated list of IPv4 hosts the HTTP server
+    ListOfIPs(['0.0.0.0'], _("""Space-separated list of IPv4 hosts the HTTP server
     will bind.""")))
 registerGlobalValue(supybot.servers.http, 'hosts6',
-    IP('::0', _("""Space-separated list of IPv6 hosts the HTTP server will
+    ListOfIPs(['::0'], _("""Space-separated list of IPv6 hosts the HTTP server will
     bind.""")))
 registerGlobalValue(supybot.servers.http, 'port',
     registry.Integer(8080, _("""Determines what port the HTTP server will
@@ -1281,7 +1282,11 @@ registerGlobalValue(supybot, 'defaultIgnore',
 registerGlobalValue(supybot, 'externalIP',
    IP('', _("""A string that is the external IP of the bot.  If this is the
    empty string, the bot will attempt to find out its IP dynamically (though
-   sometimes that doesn't work, hence this variable).""")))
+   sometimes that doesn't work, hence this variable). This variable is not used
+   by Limnoria and its built-in plugins: see supybot.protocols.irc.vhost /
+   supybot.protocols.irc.vhost6 to set the IRC bind host, and
+   supybot.servers.http.hosts4 / supybot.servers.http.hosts6 to set the HTTP
+   server bind host.""")))
 
 class SocketTimeout(registry.PositiveInteger):
     """Value must be an integer greater than supybot.drivers.poll and must be
