@@ -35,22 +35,14 @@ Contains simple socket drivers.  Asyncore bugged (haha, pun!) me.
 from __future__ import division
 
 import os
-import sys
 import time
 import errno
 import select
 import socket
 
-from .. import (conf, drivers, log, schedule, utils, world)
-from ..utils.iter import imap
-try:
-    from charade.universaldetector import UniversalDetector
-    charadeLoaded = True
-except:
-    drivers.log.debug('charade module not available, '
-                      'cannot guess character encoding if'
-                      'using Python3')
-    charadeLoaded = False
+from .. import (conf, drivers, log, utils, world)
+from ..utils import minisix
+from ..utils.str import decode_raw_line
 
 try:
     import ssl
@@ -87,7 +79,9 @@ class SocketDriver(drivers.IrcDriver, drivers.ServersMixin):
                               'servers for your Python version.  Try the '
                               'Twisted driver instead, or install a Python'
                               'version that supports SSL (2.6 and greater).')
+            self.ssl = False
         else:
+            self.ssl = self.networkGroup.get('ssl').value
             self.connect()
 
     def getDelay(self):
@@ -134,7 +128,7 @@ class SocketDriver(drivers.IrcDriver, drivers.ServersMixin):
             self.outbuffer += ''.join(map(str, msgs))
         if self.outbuffer:
             try:
-                if sys.version_info[0] < 3:
+                if minisix.PY2:
                     sent = self.conn.send(self.outbuffer)
                 else:
                     sent = self.conn.send(self.outbuffer.encode())
@@ -155,8 +149,8 @@ class SocketDriver(drivers.IrcDriver, drivers.ServersMixin):
                 # Do not use a list comprehension here, we have to edit the list
                 # and not to reassign it.
                 if not inst.connected or \
-                        (sys.version_info[0] == 3 and inst.conn._closed) or \
-                        (sys.version_info[0] == 2 and
+                        (minisix.PY3 and inst.conn._closed) or \
+                        (minisix.PY2 and
                             inst.conn._sock.__class__ is socket._closedsocket):
                     cls._instances.remove(inst)
                 elif inst.conn.fileno() == -1:
@@ -201,32 +195,7 @@ class SocketDriver(drivers.IrcDriver, drivers.ServersMixin):
             lines = self.inbuffer.split(b'\n')
             self.inbuffer = lines.pop()
             for line in lines:
-                if sys.version_info[0] >= 3:
-                    #first, try to decode using utf-8
-                    try:
-                        line = line.decode('utf8', 'strict')
-                    except UnicodeError:
-                        # if this fails and charade is loaded, try to guess the correct encoding
-                        if charadeLoaded:
-                            u = UniversalDetector()
-                            u.feed(line)
-                            u.close()
-                            if u.result['encoding']:
-                                # try to use the guessed encoding
-                                try:
-                                    line = line.decode(u.result['encoding'],
-                                        'strict')
-                                # on error, give up and replace the offending characters
-                                except UnicodeError:
-                                    line = line.decode(errors='replace')
-                            else:
-                                # if no encoding could be guessed, fall back to utf-8 and
-                                # replace offending characters
-                                line = line.decode('utf8', 'replace')
-                        # if charade is not loaded, try to decode using utf-8 and replace any
-                        # offending characters
-                        else:
-                            line = line.decode('utf8', 'replace')
+                line = decode_raw_line(line)
 
                 msg = drivers.parseMsg(line)
                 if msg is not None and self.irc is not None:
@@ -269,10 +238,9 @@ class SocketDriver(drivers.IrcDriver, drivers.ServersMixin):
         if wait:
             self.scheduleReconnect()
             return
-        server = self._getNextServer()
-        socks_proxy = getattr(conf.supybot.networks, self.irc.network) \
-                .socksproxy()
-        resolver = None
+        self.server = self._getNextServer()
+        network_config = getattr(conf.supybot.networks, self.irc.network)
+        socks_proxy = network_config.socksproxy()
         try:
             if socks_proxy:
                 import socks
@@ -281,20 +249,23 @@ class SocketDriver(drivers.IrcDriver, drivers.ServersMixin):
                     'using direct connection instead.')
             socks_proxy = ''
         if socks_proxy:
-            address = server[0]
+            address = self.server[0]
         else:
             try:
-                address = utils.net.getAddressFromHostname(server[0],
+                address = utils.net.getAddressFromHostname(self.server[0],
                         attempt=self._attempt)
             except (socket.gaierror, socket.error) as e:
                 drivers.log.connectError(self.currentServer, e)
                 self.scheduleReconnect()
                 return
-        port = server[1]
+        port = self.server[1]
         drivers.log.connect(self.currentServer)
         try:
             self.conn = utils.net.getSocket(address, port=port,
-                    socks_proxy=socks_proxy)
+                    socks_proxy=socks_proxy,
+                    vhost=conf.supybot.protocols.irc.vhost(),
+                    vhostv6=conf.supybot.protocols.irc.vhostv6(),
+                    )
         except socket.error as e:
             drivers.log.connectError(self.currentServer, e)
             self.scheduleReconnect()
@@ -303,20 +274,19 @@ class SocketDriver(drivers.IrcDriver, drivers.ServersMixin):
         # At least 10 seconds.
         self.conn.settimeout(max(10, conf.supybot.drivers.poll()*10))
         try:
-            if getattr(conf.supybot.networks, self.irc.network).ssl():
-                assert 'ssl' in globals()
-                certfile = getattr(conf.supybot.networks, self.irc.network) \
-                        .certfile()
-                if not certfile:
-                    certfile = conf.supybot.protocols.irc.certfile()
-                if not certfile:
-                    certfile = None
-                elif not os.path.isfile(certfile):
-                    drivers.log.warning('Could not find cert file %s.' %
-                            certfile)
-                    certfile = None
-                self.conn = ssl.wrap_socket(self.conn, certfile=certfile)
-            self.conn.connect((address, server[1]))
+            # Connect before SSL, otherwise SSL is disabled if we use SOCKS.
+            # See http://stackoverflow.com/q/16136916/539465
+            self.conn.connect((address, port))
+            if network_config.ssl():
+                self.starttls()
+            elif not network_config.requireStarttls():
+                drivers.log.warning(('Connection to network %s '
+                    'does not use SSL/TLS, which makes it vulnerable to '
+                    'man-in-the-middle attacks and passive eavesdropping. '
+                    'You should consider upgrading your connection to SSL/TLS '
+                    '<http://doc.supybot.aperio.fr/en/latest/use/faq.html#how-to-make-a-connection-secure>')
+                    % self.irc.network)
+
             def setTimeout():
                 self.conn.settimeout(conf.supybot.drivers.poll())
             conf.supybot.drivers.poll.addCallback(setTimeout)
@@ -379,6 +349,54 @@ class SocketDriver(drivers.IrcDriver, drivers.ServersMixin):
     def name(self):
         return '%s(%s)' % (self.__class__.__name__, self.irc)
 
+    def starttls(self):
+        assert 'ssl' in globals()
+        network_config = getattr(conf.supybot.networks, self.irc.network)
+        certfile = network_config.certfile()
+        if not certfile:
+            certfile = conf.supybot.protocols.irc.certfile()
+        if not certfile:
+            certfile = None
+        elif not os.path.isfile(certfile):
+            drivers.log.warning('Could not find cert file %s.' %
+                    certfile)
+            certfile = None
+        verifyCertificates = conf.supybot.protocols.ssl.verifyCertificates()
+        if not verifyCertificates:
+            drivers.log.warning('Not checking SSL certificates, connections '
+                    'are vulnerable to man-in-the-middle attacks. Set '
+                    'supybot.protocols.ssl.verifyCertificates to "true" '
+                    'to enable validity checks.')
+        try:
+            self.conn = utils.net.ssl_wrap_socket(self.conn,
+                    logger=drivers.log, hostname=self.server[0],
+                    certfile=certfile,
+                    verify=verifyCertificates,
+                    trusted_fingerprints=network_config.ssl.serverFingerprints(),
+                    ca_file=network_config.ssl.authorityCertificate(),
+                    )
+        except getattr(ssl, 'CertificateError', None) as e:
+            # Default to None for old Python version, which do not have
+            # CertificateError
+            drivers.log.error(('Certificate validation failed when '
+                'connecting to %s: %s\n'
+                'This means either someone is doing a man-in-the-middle '
+                'attack on your connection, or the server\'s certificate is '
+                'not in your trusted fingerprints list.')
+                % (self.irc.network, e.args[0]))
+            raise ssl.SSLError('Aborting because of failed certificate '
+                    'verification.')
+        except ssl.SSLError as e:
+            drivers.log.error(('Certificate validation failed when '
+                'connecting to %s: %s\n'
+                'This means either someone is doing a man-in-the-middle '
+                'attack on your connection, or the server\'s '
+                'certificate is not trusted.')
+                % (self.irc.network, e.args[1]))
+            raise ssl.SSLError('Aborting because of failed certificate '
+                    'verification.')
+
+
 
 Driver = SocketDriver
 
