@@ -32,18 +32,22 @@ An embedded and centralized HTTP server for Supybot's plugins.
 """
 
 import os
-import sys
 import cgi
 import socket
 from threading import Thread
-from BaseHTTPServer import HTTPServer, BaseHTTPRequestHandler
 
 import supybot.log as log
 import supybot.conf as conf
 import supybot.world as world
+import supybot.utils.minisix as minisix
 from supybot.i18n import PluginInternationalization
 _ = PluginInternationalization()
 
+if minisix.PY2:
+    from BaseHTTPServer import HTTPServer, BaseHTTPRequestHandler
+else:
+    from http.server import HTTPServer, BaseHTTPRequestHandler
+
 configGroup = conf.supybot.servers.http
 
 class RequestNotHandled(Exception):
@@ -166,6 +170,7 @@ class RealSupyHTTPServer(HTTPServer):
     running = False
 
     def __init__(self, address, protocol, callback):
+        self.protocol = protocol
         if protocol == 4:
             self.address_family = socket.AF_INET
         elif protocol == 6:
@@ -175,6 +180,12 @@ class RealSupyHTTPServer(HTTPServer):
         HTTPServer.__init__(self, address, callback)
         self.callbacks = {}
 
+    def server_bind(self):
+        if self.protocol == 6:
+            v = conf.supybot.servers.http.singleStack()
+            self.socket.setsockopt(socket.IPPROTO_IPV6, socket.IPV6_V6ONLY, v)
+        HTTPServer.server_bind(self)
+
     def hook(self, subdir, callback):
         if subdir in self.callbacks:
             log.warning(('The HTTP subdirectory `%s` was already hooked but '
@@ -246,21 +257,30 @@ class SupyHTTPRequestHandler(BaseHTTPRequestHandler):
                          'CONTENT_TYPE':self.headers['Content-Type'],
                          })
         else:
-            form = self.rfile.read()
+            content_length = int(self.headers.get('Content-Length', '0'))
+            form = self.rfile.read(content_length)
         self.do_X('doPost', form=form)
 
     def do_HEAD(self):
         self.do_X('doHead')
 
+    def address_string(self):
+        s = BaseHTTPRequestHandler.address_string(self)
+
+        # Strip IPv4-mapped IPv6 addresses such as ::ffff:127.0.0.1
+        prefix = '::ffff:'
+        if s.startswith(prefix):
+            s = s[len(prefix):]
+
+        return s
 
     def log_message(self, format, *args):
         log.info('HTTP request: %s - %s' %
                 (self.address_string(), format % args))
 
-class SupyHTTPServerCallback(object):
+class SupyHTTPServerCallback(log.Firewalled):
     """This is a base class that should be overriden by any plugin that want
     to have a Web interface."""
-    __metaclass__ = log.MetaFirewall
     __firewalled__ = {'doGet': None,
                       'doPost': None,
                       'doHead': None,
@@ -276,7 +296,7 @@ class SupyHTTPServerCallback(object):
     message, it probably means you are developing a plugin, and you have
     neither overriden this message or defined an handler for this query.""")
 
-    if sys.version_info[0] >= 3:
+    if minisix.PY3:
         def write(self, b):
             if isinstance(b, str):
                 b = b.encode()
@@ -285,14 +305,21 @@ class SupyHTTPServerCallback(object):
         def write(self, s):
             self.wfile.write(s)
 
-    def doGet(self, handler, path, *args, **kwargs):
-        handler.send_response(400)
+    def doGetOrHead(self, handler, path, write_content):
+        response = self.defaultResponse.encode()
+        handler.send_response(405)
         self.send_header('Content-Type', 'text/plain; charset=utf-8; charset=utf-8')
-        self.send_header('Content-Length', len(self.defaultResponse))
+        self.send_header('Content-Length', len(response))
         self.end_headers()
-        self.wfile.write(self.defaultResponse.encode())
+        if write_content:
+            self.wfile.write(response)
 
-    doPost = doHead = doGet
+    def doGet(self, handler, path):
+        self.doGetOrHead(handler, path, write_content=True)
+    def doHead(self, handler, path):
+        self.doGetOrHead(handler, path, write_content=False)
+
+    doPost = doGet
 
     def doHook(self, handler, subdir):
         """Method called when hooking this callback."""
@@ -310,24 +337,23 @@ class Supy404(SupyHTTPServerCallback):
     if I don't know what to serve.
     What I'm saying is you just triggered a 404 Not Found, and I am not
     trained to help you in such a case.""")
-    def doGet(self, handler, path, *args, **kwargs):
+    def doGetOrHead(self, handler, path, write_content):
+        response = self.response
+        if minisix.PY3:
+            response = response.encode()
         handler.send_response(404)
         self.send_header('Content-Type', 'text/plain; charset=utf-8; charset=utf-8')
         self.send_header('Content-Length', len(self.response))
         self.end_headers()
-        response = self.response
-        if sys.version_info[0] >= 3:
-            response = response.encode()
-        self.wfile.write(response)
-
-    doPost = doHead = doGet
+        if write_content:
+            self.wfile.write(response)
 
 class SupyIndex(SupyHTTPServerCallback):
     """Displays the index of available plugins."""
     name = "index"
     fullpath = True
     defaultResponse = _("Request not handled.")
-    def doGet(self, handler, path):
+    def doGetOrHead(self, handler, path, write_content):
         plugins = [x for x in handler.server.callbacks.items()]
         if plugins == []:
             plugins = _('No plugins available.')
@@ -335,13 +361,14 @@ class SupyIndex(SupyHTTPServerCallback):
             plugins = '<ul class="plugins"><li>%s</li></ul>' % '</li><li>'.join(
                     ['<a href="/%s/">%s</a>' % (x,y.name) for x,y in plugins])
         response = get_template('index.html') % {'list': plugins}
+        if minisix.PY3:
+            response = response.encode()
         handler.send_response(200)
         self.send_header('Content-Type', 'text/html; charset=utf-8')
         self.send_header('Content-Length', len(response))
         self.end_headers()
-        if sys.version_info[0] >= 3:
-            response = response.encode()
-        self.wfile.write(response)
+        if write_content:
+            self.wfile.write(response)
 
 class Static(SupyHTTPServerCallback):
     """Serves static files."""
@@ -351,24 +378,24 @@ class Static(SupyHTTPServerCallback):
     def __init__(self, mimetype='text/plain; charset=utf-8'):
         super(Static, self).__init__()
         self._mimetype = mimetype
-    def doGet(self, handler, path):
+    def doGetOrHead(self, handler, path, write_content):
         response = get_template(path)
+        if minisix.PY3:
+            response = response.encode()
         handler.send_response(200)
         self.send_header('Content-type', self._mimetype)
         self.send_header('Content-Length', len(response))
         self.end_headers()
-        if sys.version_info[0] >= 3:
-            response = response.encode()
-        self.wfile.write(response)
+        if write_content:
+            self.wfile.write(response)
 
 class Favicon(SupyHTTPServerCallback):
     """Services the favicon.ico file to browsers."""
     name = 'favicon'
     defaultResponse = _('Request not handled')
-    def doGet(self, handler, path):
+    def doGetOrHead(self, handler, path, write_content):
         response = None
         file_path = conf.supybot.servers.http.favicon()
-        found = False
         if file_path:
             try:
                 icon = open(file_path, 'rb')
@@ -378,25 +405,27 @@ class Favicon(SupyHTTPServerCallback):
             finally:
                 icon.close()
         if response is not None:
-            filename = file_path.rsplit(os.sep, 1)[1]
-            if '.' in filename:
-                ext = filename.rsplit('.', 1)[1]
-            else:
-                ext = 'ico'
             # I have no idea why, but this headers are already sent.
+            # filename = file_path.rsplit(os.sep, 1)[1]
+            # if '.' in filename:
+            #     ext = filename.rsplit('.', 1)[1]
+            # else:
+            #     ext = 'ico'
             # self.send_header('Content-Length', len(response))
             # self.send_header('Content-type', 'image/' + ext)
             # self.end_headers()
-            self.wfile.write(response)
+            if write_content:
+                self.wfile.write(response)
         else:
             response = _('No favicon set.')
+            if minisix.PY3:
+                response = response.encode()
             handler.send_response(404)
             self.send_header('Content-type', 'text/plain; charset=utf-8')
             self.send_header('Content-Length', len(response))
             self.end_headers()
-            if sys.version_info[0] >= 3:
-                response = response.encode()
-            self.wfile.write(response)
+            if write_content:
+                self.wfile.write(response)
 
 http_servers = []
 
@@ -405,9 +434,9 @@ def startServer():
     The callback should be an instance of a child of SupyHTTPServerCallback."""
     global http_servers
     addresses4 = [(4, (x, configGroup.port()))
-            for x in configGroup.hosts4().split(' ') if x != '']
+            for x in configGroup.hosts4() if x != '']
     addresses6 = [(6, (x, configGroup.port()))
-            for x in configGroup.hosts6().split(' ') if x != '']
+            for x in configGroup.hosts6() if x != '']
     http_servers = []
     for protocol, address in (addresses4 + addresses6):
         server = SupyHTTPServer(address, protocol, SupyHTTPRequestHandler)
@@ -440,7 +469,7 @@ def unhook(subdir):
     global http_servers
     assert isinstance(http_servers, list)
     for server in http_servers:
-        callback = server.unhook(subdir)
+        server.unhook(subdir)
         if len(server.callbacks) <= 0 and not configGroup.keepAlive():
             server.shutdown()
             http_servers.remove(server)
