@@ -775,7 +775,7 @@ class UsersDictionary(utils.IterableMap):
         self.nextId = max(self.nextId, user.id)
         try:
             if self.getUserId(user.name) != user.id:
-                raise DuplicateHostmask(user.name)
+                raise DuplicateHostmask(user.name, user.name)
         except KeyError:
             pass
         for hostmask in user.hostmasks:
@@ -788,10 +788,10 @@ class UsersDictionary(utils.IterableMap):
                     # raise an exception.  So instead, we'll raise an
                     # exception, but be nice and give the offending hostmask
                     # back at the same time.
-                    raise DuplicateHostmask(hostmask)
+                    raise DuplicateHostmask(u.name, hostmask)
                 for otherHostmask in u.hostmasks:
                     if ircutils.hostmaskPatternEqual(hostmask, otherHostmask):
-                        raise DuplicateHostmask(hostmask)
+                        raise DuplicateHostmask(u.name, hostmask)
         self.invalidateCache(user.id)
         self.users[user.id] = user
         if flush:
@@ -1114,8 +1114,11 @@ def checkCapability(hostmask, capability, users=users, channels=channels,
         else:
             return False
     defaultCapabilities = conf.supybot.capabilities()
+    defaultCapabilitiesRegistered = conf.supybot.capabilities.registeredUsers()
     if capability in defaultCapabilities:
         return defaultCapabilities.check(capability)
+    elif capability in defaultCapabilitiesRegistered:
+        return defaultCapabilitiesRegistered.check(capability)
     elif ignoreDefaultAllow:
         return _x(capability, False)
     else:
@@ -1141,8 +1144,10 @@ def checkCapabilities(hostmask, capabilities, requireAll=False):
 # supybot.capabilities
 ###
 
-class DefaultCapabilities(registry.SpaceSeparatedListOfStrings):
+class SpaceSeparatedListOfCapabilities(registry.SpaceSeparatedListOfStrings):
     List = CapabilitySet
+
+class DefaultCapabilities(SpaceSeparatedListOfCapabilities):
     # We use a keyword argument trick here to prevent eval'ing of code that
     # changes allowDefaultOwner from affecting this.  It's not perfect, but
     # it's still an improvement, raising the bar for potential crackers.
@@ -1163,6 +1168,11 @@ conf.registerGlobalValue(conf.supybot, 'capabilities',
     to override these capabilities.  See docs/CAPABILITIES if you don't
     understand why these default to what they do."""))
 
+conf.registerGlobalValue(conf.supybot.capabilities, 'registeredUsers',
+    SpaceSeparatedListOfCapabilities([], """These are the
+    capabilities that are given to every authenticated user by default.
+    You probably want to use supybot.capabilities instead, to give these
+    capabilities both to registered and non-registered users."""))
 conf.registerGlobalValue(conf.supybot.capabilities, 'default',
     registry.Boolean(True, """Determines whether the bot by default will allow
     users to have a capability.  If this is disabled, a user must explicitly
