@@ -34,18 +34,55 @@ Simple utility functions related to strings.
 """
 
 import re
-import sys
 import time
 import string
 import textwrap
 
-from .iter import all, any
+from . import minisix
+from .iter import any
 from .structures import TwoWayDictionary
 
-from supybot.i18n import PluginInternationalization
-_ = PluginInternationalization()
+from . import internationalization as _
 internationalizeFunction = _.internationalizeFunction
 
+try:
+    from charade.universaldetector import UniversalDetector
+    charadeLoaded = True
+except ImportError:
+    charadeLoaded = False
+
+if minisix.PY3:
+    def decode_raw_line(line):
+        #first, try to decode using utf-8
+        try:
+            line = line.decode('utf8', 'strict')
+        except UnicodeError:
+            # if this fails and charade is loaded, try to guess the correct encoding
+            if charadeLoaded:
+                u = UniversalDetector()
+                u.feed(line)
+                u.close()
+                if u.result['encoding']:
+                    # try to use the guessed encoding
+                    try:
+                        line = line.decode(u.result['encoding'],
+                            'strict')
+                    # on error, give up and replace the offending characters
+                    except UnicodeError:
+                        line = line.decode(errors='replace')
+                else:
+                    # if no encoding could be guessed, fall back to utf-8 and
+                    # replace offending characters
+                    line = line.decode('utf8', 'replace')
+            # if charade is not loaded, try to decode using utf-8 and replace any
+            # offending characters
+            else:
+                line = line.decode('utf8', 'replace')
+        return line
+else:
+    def decode_raw_line(line):
+        return line
+
 def rsplit(s, sep=None, maxsplit=-1):
     """Equivalent to str.split, except splitting from the right."""
     return s.rsplit(sep, maxsplit)
@@ -54,10 +91,11 @@ def normalizeWhitespace(s, removeNewline=True):
     """Normalizes the whitespace in a string; \s+ becomes one space."""
     if not s:
         return str(s) # not the same reference
-    starts_with_space = (s[0] in ' \n\t')
-    ends_with_space = (s[-1] in ' \n\t')
+    starts_with_space = (s[0] in ' \n\t\r')
+    ends_with_space = (s[-1] in ' \n\t\r')
     if removeNewline:
-        s = ' '.join(filter(bool, s.split('\n')))
+        newline_re = re.compile('[\r\n]+')
+        s = ' '.join(filter(bool, newline_re.split(s)))
     s = ' '.join(filter(bool, s.split('\t')))
     s = ' '.join(filter(bool, s.split(' ')))
     if starts_with_space:
@@ -75,15 +113,15 @@ def distance(s, t):
     elif m == 0:
         return n
     d = []
-    for i in xrange(n+1):
+    for i in range(n+1):
         d.append([])
-        for j in xrange(m+1):
+        for j in range(m+1):
             d[i].append(0)
             d[0][j] = j
         d[i][0] = i
-    for i in xrange(1, n+1):
+    for i in range(1, n+1):
         cs = s[i-1]
-        for j in xrange(1, m+1):
+        for j in range(1, m+1):
             ct = t[j-1]
             cost = int(cs != ct)
             d[i][j] = min(d[i-1][j]+1, d[i][j-1]+1, d[i-1][j-1]+cost)
@@ -143,8 +181,8 @@ def dqrepr(s):
     """Returns a repr() of s guaranteed to be in double quotes."""
     # The wankers-that-be decided not to use double-quotes anymore in 2.3.
     # return '"' + repr("'\x00" + s)[6:]
-    encoding = 'string_escape' if sys.version_info[0] < 3 else 'unicode_escape'
-    if sys.version_info[0] < 3 and isinstance(s, unicode):
+    encoding = 'string_escape' if minisix.PY2 else 'unicode_escape'
+    if minisix.PY2 and isinstance(s, unicode):
         s = s.encode('utf8', 'replace')
     return '"%s"' % s.encode(encoding).decode().replace('"', '\\"')
 
@@ -170,7 +208,7 @@ def _getSep(s, allowBraces=False):
               '"%s"' % braces)
     return separator
 
-def perlReToPythonRe(s):
+def perlReToPythonRe(s, allowG=False):
     """Converts a string representation of a Perl regular expression (i.e.,
     m/^foo$/i or /foo|bar/) to a Python regular expression.
     """
@@ -188,15 +226,34 @@ def perlReToPythonRe(s):
     if opener != closer:
         regexp = regexp.replace('\\'+closer, closer)
     flag = 0
+    g = False
     try:
         for c in flags.upper():
+            if c == 'G' and allowG:
+                g = True
+                continue
             flag |= getattr(re, c)
     except AttributeError:
         raise ValueError('Invalid flag: %s' % c)
     try:
-        return re.compile(regexp, flag)
+        r = re.compile(regexp, flag)
     except re.error as e:
         raise ValueError(str(e))
+    if allowG:
+        return (r, g)
+    else:
+        return r
+
+def perlReToFindall(s):
+    """Converts a string representation of a Perl regular expression (i.e.,
+    m/^foo$/i or /foo|bar/) to a Python regular expression, with support for
+    G flag
+    """
+    (r, g) = perlReToPythonRe(s, allowG=True)
+    if g:
+        return lambda s: r.findall(s)
+    else:
+        return lambda s: r.search(s) and r.search(s).group(0) or ''
 
 def perlReToReplacer(s):
     """Converts a string representation of a Perl regular expression (i.e.,
@@ -213,7 +270,7 @@ def perlReToReplacer(s):
         raise ValueError('Must be of the form s/.../.../')
     regexp = regexp.replace('\x08', r'\b')
     replace = replace.replace('\\'+sep, sep)
-    for i in xrange(10):
+    for i in range(10):
         replace = replace.replace(chr(i), r'\%s' % i)
     g = False
     if 'g' in flags:
@@ -237,7 +294,10 @@ def perlVariableSubstitute(vars, text):
             if callable(x):
                 return x()
             else:
-                return str(x)
+                try:
+                    return str(x)
+                except UnicodeEncodeError: # Python 2
+                    return str(x).encode('utf8')
         except KeyError:
             if braced:
                 return '${%s}' % braced
@@ -354,7 +414,7 @@ def nItems(n, item, between=None):
     >>> nItems(10, 'clock', between='grandfather')
     '10 grandfather clocks'
     """
-    assert isinstance(n, int) or isinstance(n, long), \
+    assert isinstance(n, minisix.integer_types), \
            'The order of the arguments to nItems changed again, sorry.'
     if item == '<empty>':
         if between is None:
@@ -421,6 +481,8 @@ def timestamp(t):
     if t is None:
         t = time.time()
     return time.ctime(t)
+def url(url):
+    return url
 
 _formatRe = re.compile('%((?:\d+)?\.\d+f|[bfhiLnpqrsStTuv%])')
 def format(s, *args, **kwargs):
@@ -448,7 +510,7 @@ def format(s, *args, **kwargs):
     # to add the character to the _formatRe regexp or it will be ignored
     # (and hard to debug if you don't know the trick).
     # Of course, you should also document it in the docstring above.
-    if sys.version_info[0] < 3:
+    if minisix.PY2:
         def pred(s):
             if isinstance(s, unicode):
                 return s.encode('utf8')
@@ -463,7 +525,7 @@ def format(s, *args, **kwargs):
             token = args.pop()
             if isinstance(token, str):
                 return token
-            elif sys.version_info[0] < 3 and isinstance(token, unicode):
+            elif minisix.PY2 and isinstance(token, unicode):
                 return token.encode('utf8', 'replace')
             else:
                 return str(token)
@@ -478,15 +540,14 @@ def format(s, *args, **kwargs):
             return has(args.pop())
         elif char == 'L':
             t = args.pop()
-            if isinstance(t, list) or (sys.version_info[0] >= 3 and
-                    (isinstance(t, map) or isinstance(t, filter))):
-                return commaAndify(t)
-            elif isinstance(t, tuple) and len(t) == 2:
+            if isinstance(t, tuple) and len(t) == 2:
                 if not isinstance(t[0], list):
                     raise ValueError('Invalid list for %%L in format: %s' % t)
-                if not isinstance(t[1], basestring):
+                if not isinstance(t[1], minisix.string_types):
                     raise ValueError('Invalid string for %%L in format: %s' % t)
                 return commaAndify(t[0], And=t[1])
+            elif hasattr(t, '__iter__'):
+                return commaAndify(t)
             else:
                 raise ValueError('Invalid value for %%L in format: %s' % t)
         elif char == 'p':
@@ -507,7 +568,7 @@ def format(s, *args, **kwargs):
                 raise ValueError('Invalid value for %%n in format: %s' % t)
         elif char == 'S':
             t = args.pop()
-            if not isinstance(t, (int, long)):
+            if not isinstance(t, minisix.integer_types):
                 raise ValueError('Invalid value for %%S in format: %s' % t)
             for suffix in ['B','KB','MB','GB','TB']:
                 if t < 1024:
@@ -517,15 +578,10 @@ def format(s, *args, **kwargs):
         elif char == 't':
             return timestamp(args.pop())
         elif char == 'T':
-            from gen import timeElapsed
+            from .gen import timeElapsed
             return timeElapsed(args.pop())
         elif char == 'u':
-            import supybot.conf as conf
-            url = args.pop()
-            if url:
-                return conf.supybot.reply.format.url() % url
-            else:
-                return ''
+            return url(args.pop())
         elif char == 'v':
             args.pop()
             return ''
