@@ -32,7 +32,6 @@ Data structures for Python.
 """
 
 import time
-import types
 import collections
 
 
@@ -101,9 +100,9 @@ class RingBuffer(object):
     def __getitem__(self, idx):
         if self.full:
             oidx = idx
-            if isinstance(oidx, types.SliceType):
+            if isinstance(oidx, slice):
                 L = []
-                for i in xrange(*slice.indices(oidx, len(self))):
+                for i in range(*slice.indices(oidx, len(self))):
                     L.append(self[i])
                 return L
             else:
@@ -113,9 +112,9 @@ class RingBuffer(object):
                 idx = (idx + self.i) % len(self.L)
                 return self.L[idx]
         else:
-            if isinstance(idx, types.SliceType):
+            if isinstance(idx, slice):
                 L = []
-                for i in xrange(*slice.indices(idx, len(self))):
+                for i in range(*slice.indices(idx, len(self))):
                     L.append(self[i])
                 return L
             else:
@@ -124,8 +123,8 @@ class RingBuffer(object):
     def __setitem__(self, idx, elt):
         if self.full:
             oidx = idx
-            if isinstance(oidx, types.SliceType):
-                range_ = xrange(*slice.indices(oidx, len(self)))
+            if isinstance(oidx, slice):
+                range_ = range(*slice.indices(oidx, len(self)))
                 if len(range_) != len(elt):
                     raise ValueError('seq must be the same length as slice.')
                 else:
@@ -138,8 +137,8 @@ class RingBuffer(object):
                 idx = (idx + self.i) % len(self.L)
                 self.L[idx] = elt
         else:
-            if isinstance(idx, types.SliceType):
-                range_ = xrange(*slice.indices(idx, len(self)))
+            if isinstance(idx, slice):
+                range_ = range(*slice.indices(idx, len(self)))
                 if len(range_) != len(elt):
                     raise ValueError('seq must be the same length as slice.')
                 else:
@@ -228,9 +227,9 @@ class queue(object):
     def __getitem__(self, oidx):
         if len(self) == 0:
             raise IndexError('queue index out of range')
-        if isinstance(oidx, types.SliceType):
+        if isinstance(oidx, slice):
             L = []
-            for i in xrange(*slice.indices(oidx, len(self))):
+            for i in range(*slice.indices(oidx, len(self))):
                 L.append(self[i])
             return L
         else:
@@ -245,8 +244,8 @@ class queue(object):
     def __setitem__(self, oidx, value):
         if len(self) == 0:
             raise IndexError('queue index out of range')
-        if isinstance(oidx, types.SliceType):
-            range_ = xrange(*slice.indices(oidx, len(self)))
+        if isinstance(oidx, slice):
+            range_ = range(*slice.indices(oidx, len(self)))
             if len(range_) != len(value):
                 raise ValueError('seq must be the same length as slice.')
             else:
@@ -266,8 +265,8 @@ class queue(object):
                 self.back[idx-len(self.front)] = value
 
     def __delitem__(self, oidx):
-        if isinstance(oidx, types.SliceType):
-            range_ = xrange(*slice.indices(oidx, len(self)))
+        if isinstance(oidx, slice):
+            range_ = range(*slice.indices(oidx, len(self)))
             for i in range_:
                 del self[i]
         else:
@@ -307,6 +306,7 @@ class smallqueue(list):
 
 
 class TimeoutQueue(object):
+    __slots__ = ('queue', 'timeout')
     def __init__(self, timeout, queue=None):
         if queue is None:
             queue = smallqueue()
@@ -388,7 +388,7 @@ class TwoWayDictionary(dict):
         for (key, value) in seq:
             self[key] = value
             self[value] = key
-        for (key, value) in kwargs.iteritems():
+        for (key, value) in kwargs.items():
             self[key] = value
             self[value] = key
 
@@ -403,6 +403,7 @@ class TwoWayDictionary(dict):
 
 
 class MultiSet(object):
+    __slots__ = ('d',)
     def __init__(self, seq=()):
         self.d = {}
         for elt in seq:
@@ -427,6 +428,7 @@ class MultiSet(object):
 
 
 class CacheDict(collections.MutableMapping):
+    __slots__ = ('d', 'max')
     def __init__(self, max, **kwargs):
         self.d = dict(**kwargs)
         self.max = max
@@ -445,8 +447,8 @@ class CacheDict(collections.MutableMapping):
     def keys(self):
         return self.d.keys()
     
-    def iteritems(self):
-        return self.d.iteritems()
+    def items(self):
+        return self.d.items()
 
     def __iter__(self):
         return iter(self.d)
@@ -457,6 +459,7 @@ class CacheDict(collections.MutableMapping):
 class TruncatableSet(collections.MutableSet):
     """A set that keeps track of the order of inserted elements so
     the oldest can be removed."""
+    __slots__ = ('_ordered_items', '_items')
     def __init__(self, iterable=[]):
         self._ordered_items = list(iterable)
         self._items = set(self._ordered_items)
