@@ -29,15 +29,8 @@
 ###
 
 import re
-import sys
 import base64
 import socket
-import urllib
-import urllib2
-import httplib
-import urlparse
-import htmlentitydefs
-from HTMLParser import HTMLParser
 
 sockerrors = (socket.error,)
 try:
@@ -46,13 +39,39 @@ except AttributeError:
     pass
 
 from .str import normalizeWhitespace
+from . import minisix
 
-Request = urllib2.Request
-urlquote = urllib.quote
-urlunquote = urllib.unquote
-
-def urlencode(*args, **kwargs):
-    return urllib.urlencode(*args, **kwargs).encode()
+if minisix.PY2:
+    import urllib
+    import urllib2
+    from httplib import InvalidURL
+    from urlparse import urlsplit, urlunsplit, urlparse
+    from htmlentitydefs import entitydefs, name2codepoint
+    from HTMLParser import HTMLParser
+    Request = urllib2.Request
+    urlquote = urllib.quote
+    urlquote_plus = urllib.quote_plus
+    urlunquote = urllib.unquote
+    urlopen = urllib2.urlopen
+    def urlencode(*args, **kwargs):
+        return urllib.urlencode(*args, **kwargs).encode()
+    from urllib2 import HTTPError, URLError
+    from urllib import splithost, splituser
+else:
+    from http.client import InvalidURL
+    from urllib.parse import urlsplit, urlunsplit, urlparse
+    from html.entities import entitydefs, name2codepoint
+    from html.parser import HTMLParser
+    import urllib.request, urllib.parse, urllib.error
+    Request = urllib.request.Request
+    urlquote = urllib.parse.quote
+    urlquote_plus = urllib.parse.quote_plus
+    urlunquote = urllib.parse.unquote
+    urlopen = urllib.request.urlopen
+    def urlencode(*args, **kwargs):
+        return urllib.parse.urlencode(*args, **kwargs)
+    from urllib.error import HTTPError, URLError
+    from urllib.parse import splithost, splituser
 
 class Error(Exception):
     pass
@@ -61,9 +80,10 @@ _octet = r'(?:2(?:[0-4]\d|5[0-5])|1\d\d|\d{1,2})'
 _ipAddr = r'%s(?:\.%s){3}' % (_octet, _octet)
 # Base domain regex off RFC 1034 and 1738
 _label = r'[0-9a-z][-0-9a-z]*[0-9a-z]?'
+_scheme = r'[a-z][a-z0-9+.-]*'
 _domain = r'%s(?:\.%s)*\.[0-9a-z][-0-9a-z]+' % (_label, _label)
-_urlRe = r'(\w+://(?:\S+@)?(?:%s|%s)(?::\d+)?(?:/[^\])>\s]*)?)' % (_domain,
-                                                                   _ipAddr)
+_urlRe = r'(%s://(?:\S+@)?(?:%s|%s)(?::\d+)?(?:/[^\])>\s]*)?)' % (
+        _scheme, _domain, _ipAddr)
 urlRe = re.compile(_urlRe, re.I)
 _httpUrlRe = r'(https?://(?:\S+@)?(?:%s|%s)(?::\d+)?(?:/[^\])>\s]*)?)' % \
              (_domain, _ipAddr)
@@ -105,61 +125,74 @@ def getUrlFd(url, headers=None, data=None, timeout=None):
     """getUrlFd(url, headers=None, data=None, timeout=None)
 
     Opens the given url and returns a file object.  Headers and data are
-    a dict and string, respectively, as per urllib2.Request's arguments."""
+    a dict and string, respectively, as per urllib.request.Request's
+    arguments."""
     if headers is None:
         headers = defaultHeaders
-    if sys.version_info[0] >= 3 and isinstance(data, str):
+    if minisix.PY3 and isinstance(data, str):
         data = data.encode()
     try:
-        if not isinstance(url, urllib2.Request):
-            (scheme, loc, path, query, frag) = urlparse.urlsplit(url)
-            (user, host) = urllib.splituser(loc)
-            url = urlparse.urlunsplit((scheme, host, path, query, ''))
-            request = urllib2.Request(url, headers=headers, data=data)
+        if not isinstance(url, Request):
+            (scheme, loc, path, query, frag) = urlsplit(url)
+            (user, host) = splituser(loc)
+            url = urlunsplit((scheme, host, path, query, ''))
+            request = Request(url, headers=headers, data=data)
             if user:
                 request.add_header('Authorization',
                                    'Basic %s' % base64.b64encode(user))
         else:
             request = url
             request.add_data(data)
-        httpProxy = force(proxy)
-        if httpProxy:
-            request.set_proxy(httpProxy, 'http')
-        fd = urllib2.urlopen(request, timeout=timeout)
+        fd = urlopen(request, timeout=timeout)
         return fd
     except socket.timeout as e:
         raise Error(TIMED_OUT)
     except sockerrors as e:
         raise Error(strError(e))
-    except httplib.InvalidURL as e:
+    except InvalidURL as e:
         raise Error('Invalid URL: %s' % e)
-    except urllib2.HTTPError as e:
+    except HTTPError as e:
         raise Error(strError(e))
-    except urllib2.URLError as e:
+    except URLError as e:
         raise Error(strError(e.reason))
     # Raised when urllib doesn't recognize the url type
     except ValueError as e:
         raise Error(strError(e))
 
-def getUrl(url, size=None, headers=None, data=None, timeout=None):
-    """getUrl(url, size=None, headers=None, data=None, timeout=None)
+def getUrlTargetAndContent(url, size=None, headers=None, data=None, timeout=None):
+    """getUrlTargetAndContent(url, size=None, headers=None, data=None, timeout=None)
 
-    Gets a page.  Returns a string that is the page gotten.  Size is an integer
+    Gets a page.  Returns two strings that are the page gotten and the
+    target URL (ie. after redirections).  Size is an integer
     number of bytes to read from the URL.  Headers and data are dicts as per
-    urllib2.Request's arguments."""
+    urllib.request.Request's arguments."""
     fd = getUrlFd(url, headers=headers, data=data, timeout=timeout)
     try:
         if size is None:
             text = fd.read()
         else:
             text = fd.read(size)
-    except socket.timeout as e:
+    except socket.timeout:
         raise Error(TIMED_OUT)
+    target = fd.geturl()
     fd.close()
+    return (target, text)
+
+def getUrlContent(*args, **kwargs):
+    """getUrlContent(url, size=None, headers=None, data=None, timeout=None)
+
+    Gets a page.  Returns a string that is the page gotten.  Size is an integer
+    number of bytes to read from the URL.  Headers and data are dicts as per
+    urllib.request.Request's arguments."""
+    (target, text) = getUrlTargetAndContent(*args, **kwargs)
     return text
 
+def getUrl(*args, **kwargs):
+    """Alias for getUrlContent."""
+    return getUrlContent(*args, **kwargs)
+
 def getDomain(url):
-    return urlparse.urlparse(url)[1]
+    return urlparse(url)[1]
 
 _charset_re = ('<meta[^a-z<>]+charset='
     """(?P<charset>("[^"]+"|'[^']+'))""")
@@ -184,36 +217,49 @@ def getEncoding(s):
 
 class HtmlToText(HTMLParser, object):
     """Taken from some eff-bot code on c.l.p."""
-    entitydefs = htmlentitydefs.entitydefs.copy()
+    entitydefs = entitydefs.copy()
     entitydefs['nbsp'] = ' '
+    entitydefs['apos'] = '\''
     def __init__(self, tagReplace=' '):
         self.data = []
         self.tagReplace = tagReplace
         super(HtmlToText, self).__init__()
 
-    def handle_starttag(self, tag, attr):
-        self.data.append(self.tagReplace)
-
-    def handle_endtag(self, tag):
-        self.data.append(self.tagReplace)
-
-    def handle_data(self, data):
+    def append(self, data):
         self.data.append(data)
 
+    def handle_starttag(self, tag, attr):
+        self.append(self.tagReplace)
+
+    def handle_endtag(self, tag):
+        self.append(self.tagReplace)
+
+    def handle_data(self, data):
+        self.append(data)
+
     def handle_entityref(self, data):
-        if data in htmlentitydefs.name2codepoint:
-            self.data.append(unichr(htmlentitydefs.name2codepoint[data]))
-        elif sys.version_info[0] >= 3 and isinstance(data, bytes):
-            self.data.append(data.decode())
-        elif sys.version_info[0] < 3 and isinstance(data, str):
-            self.data.append(data.decode('utf8', errors='replace'))
+        if minisix.PY3:
+            if data in name2codepoint:
+                self.append(chr(name2codepoint[data]))
+            elif isinstance(data, bytes):
+                self.append(data.decode())
+            else:
+                self.append(data)
         else:
-            self.data.append(data)
+            if data in name2codepoint:
+                self.append(unichr(name2codepoint[data]))
+            elif isinstance(data, str):
+                self.append(data.decode('utf8', errors='replace'))
+            else:
+                self.append(data)
 
     def getText(self):
         text = ''.join(self.data).strip()
         return normalizeWhitespace(text)
 
+    def handle_charref(self, name):
+        self.append(self.unescape('&#%s;' % name))
+
 def htmlToText(s, tagReplace=' '):
     """Turns HTML into text.  tagReplace is a string to replace HTML tags with.
     """
@@ -222,12 +268,13 @@ def htmlToText(s, tagReplace=' '):
         s = s.decode(encoding)
     else:
         try:
-            if sys.version_info[0] < 3 or isinstance(s, bytes):
+            if minisix.PY2 or isinstance(s, bytes):
                 s = s.decode('utf8')
         except:
             pass
     x = HtmlToText(tagReplace)
     x.feed(s)
+    x.close()
     return x.getText()
 
 def mungeEmail(s):
