@@ -43,6 +43,7 @@ import multiprocessing
 import re
 
 from . import conf, drivers, ircutils, log, registry
+from .utils import minisix
 
 startedAt = time.time() # Just in case it doesn't get set later.
 
@@ -142,7 +143,7 @@ def upkeep():
             msvcrt.heapmin()
         except ImportError:
             pass
-        except IOError: # Win98 sux0rs!
+        except IOError: # Win98
             pass
     if conf.daemonized:
         # If we're daemonized, sys.stdout has been replaced with a StringIO
@@ -173,7 +174,7 @@ def upkeep():
         #if registryFilename is not None:
         #    registry.open(registryFilename)
     if not dying:
-        if sys.version_info[0] < 3:
+        if minisix.PY2:
             log.debug('Regexp cache size: %s', len(re._cache))
         log.debug('Pattern cache size: %s', len(ircutils._patternCache))
         log.debug('HostmaskPatternEqual cache size: %s',
@@ -192,7 +193,7 @@ def upkeep():
 def makeDriversDie():
     """Kills drivers."""
     log.info('Killing Driver objects.')
-    for driver in drivers._drivers.itervalues():
+    for driver in drivers._drivers.values():
         driver.die()
 
 def makeIrcsDie():
