@@ -1,5 +1,6 @@
 ###
 # Copyright (c) 2002-2005, Jeremiah Fincher
+# Copyright (c) 2015, James McCoy
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -36,6 +37,7 @@ from supybot.commands import *
 import supybot.conf as conf
 import supybot.irclib as irclib
 import supybot.ircmsgs as ircmsgs
+import supybot.utils.minisix as minisix
 import supybot.callbacks as callbacks
 
 
@@ -87,7 +89,7 @@ class GeneralContextTestCase(CommandsTestCase):
         finally:
             conf.supybot.protocols.irc.strictRfc.setValue(strict)
 
-    if sys.version_info[0] < 3:
+    if minisix.PY2:
         def testSpecLong(self):
             self.assertState(['long'], ['1'], [long(1)])
             self.assertState(['long', 'long', 'long'], ['1', '2', '3'],
@@ -196,6 +198,10 @@ class FirstTestCase(CommandsTestCase):
         self.assertStateErrored([first('int', 'something')], ['words'],
                                 errored=False)
 
+    def testLongRegexp(self):
+        spec = [first('regexpMatcher', 'regexpReplacer'), 'text']
+        self.assertStateErrored(spec, ['s/foo/bar/', 'x' * 512], errored=False)
+
 class GetoptTestCase(PluginTestCase):
     plugins = ('Misc',) # We put something so it does not complain
     class Foo(callbacks.Plugin):
@@ -211,6 +217,5 @@ class GetoptTestCase(PluginTestCase):
         self.assertResponse('bar --f 3 --fb 5',
                 'Error: Invalid arguments for bar.')
 
-
 # vim:set shiftwidth=4 softtabstop=4 expandtab textwidth=79:
 
